kedro.framework.context — Kedro 0.17.6 documentation

# kedro.framework.context

Description

`kedro.framework.context` provides functionality for loading Kedro project context.

Classes

`kedro.framework.context.KedroContext`(…[, …]) | `KedroContext` is the base class which holds the configuration and Kedro’s main functionality.

Exceptions

`kedro.framework.context.KedroContextError` | Error occurred when loading project and running context pipeline.